aboutsummaryrefslogtreecommitdiffhomepage
path: root/include
diff options
context:
space:
mode:
authorGravatar Jim Van Verth <jvanverth@google.com>2017-12-13 09:26:37 -0500
committerGravatar Skia Commit-Bot <skia-commit-bot@chromium.org>2017-12-13 14:54:42 +0000
commit76d917cef19aabfdc1247336f58237800bd71875 (patch)
tree6e6be4dc09150c4d9e8f74bb80c866f5062278ed /include
parent1fbdb61f1389f01ce1cf1b7950e03a84811a9f38 (diff)
Ensure we flush TextBlobCache message queue.
If we create and delete TextBlobs without actually renderering them, their deletion messages can back up in the message queue. This adds a routine to GrContext to ensure these messages get flushed. Bug: 703297 Change-Id: Icc222373ac2a954dc3b77190cad79070ea562ba2 Reviewed-on: https://skia-review.googlesource.com/82686 Commit-Queue: Jim Van Verth <jvanverth@google.com> Reviewed-by: Brian Salomon <bsalomon@google.com>
Diffstat (limited to 'include')
-rw-r--r--include/gpu/GrContext.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h
index 02b26a8aa5..d9ea0a0ce8 100644
--- a/include/gpu/GrContext.h
+++ b/include/gpu/GrContext.h
@@ -190,10 +190,10 @@ public:
void purgeAllUnlockedResources();
/**
* Purge GPU resources that haven't been used in the past 'ms' milliseconds, regardless of
* whether the context is currently under budget.
*/
- void purgeResourcesNotUsedInMs(std::chrono::milliseconds ms);
+ void performDeferredCleanup(std::chrono::milliseconds msNotUsed);
/**
* Purge unlocked resources from the cache until the the provided byte count has been reached
@@ -190,10 +190,10 @@ public:
void purgeAllUnlockedResources();
/**
- * Purge GPU resources that haven't been used in the past 'ms' milliseconds, regardless of
- * whether the context is currently under budget.
+ * Purge GPU resources that haven't been used in the past 'msNotUsed' milliseconds or are
+ * otherwise marked for deletion, regardless of whether the context is under budget.
*/